@@ -3,7 +3,7 @@
 SEXP logical_to_bytes(SEXP x) {
   int * data = INTEGER(x);
   size_t len = LENGTH(x) * sizeof(int);
-  SEXP ret = PROTECT(allocVector(RAWSXP, len));
+  SEXP ret = PROTECT(Rf_allocVector(RAWSXP, len));
   memcpy(RAW(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -13,7 +13,7 @@ SEXP bytes_to_logical(SEXP x) {
   void * data = RAW(x);
   size_t len = LENGTH(x);
   size_t n = len / sizeof(int);
-  SEXP ret = PROTECT(allocVector(LGLSXP, n));
+  SEXP ret = PROTECT(Rf_allocVector(LGLSXP, n));
   memcpy(INTEGER(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -22,7 +22,7 @@ SEXP bytes_to_logical(SEXP x) {
 SEXP int_to_bytes(SEXP x) {
   int * data = INTEGER(x);
   size_t len = LENGTH(x) * sizeof(int);
-  SEXP ret = PROTECT(allocVector(RAWSXP, len));
+  SEXP ret = PROTECT(Rf_allocVector(RAWSXP, len));
   memcpy(RAW(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -32,7 +32,7 @@ SEXP bytes_to_int(SEXP x) {
   void * data = RAW(x);
   size_t len = LENGTH(x);
   size_t n = len / sizeof(int);
-  SEXP ret = PROTECT(allocVector(INTSXP, n));
+  SEXP ret = PROTECT(Rf_allocVector(INTSXP, n));
   memcpy(INTEGER(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -41,7 +41,7 @@ SEXP bytes_to_int(SEXP x) {
 SEXP double_to_bytes(SEXP x) {
   double * data = REAL(x);
   size_t len = LENGTH(x) * sizeof(double);
-  SEXP ret = PROTECT(allocVector(RAWSXP, len));
+  SEXP ret = PROTECT(Rf_allocVector(RAWSXP, len));
   memcpy(RAW(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -51,7 +51,7 @@ SEXP bytes_to_double(SEXP x) {
   void * data = RAW(x);
   size_t len = LENGTH(x);
   size_t n = len / sizeof(double);
-  SEXP ret = PROTECT(allocVector(REALSXP, n));
+  SEXP ret = PROTECT(Rf_allocVector(REALSXP, n));
   memcpy(REAL(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -60,7 +60,7 @@ SEXP bytes_to_double(SEXP x) {
 SEXP complex_to_bytes(SEXP x) {
   Rcomplex * data = COMPLEX(x);
   size_t len = LENGTH(x) * sizeof(Rcomplex);
-  SEXP ret = PROTECT(allocVector(RAWSXP, len));
+  SEXP ret = PROTECT(Rf_allocVector(RAWSXP, len));
   memcpy(RAW(ret), data, len);
   UNPROTECT(1);
   return ret;
@@ -70,25 +70,25 @@ SEXP bytes_to_complex(SEXP x) {
   void * data = RAW(x);
   size_t len = LENGTH(x);
   size_t n = len / sizeof(Rcomplex);
-  SEXP ret = PROTECT(allocVector(CPLXSXP, n));
+  SEXP ret = PROTECT(Rf_allocVector(CPLXSXP, n));
   memcpy(COMPLEX(ret), data, len);
   UNPROTECT(1);
   return ret;
 }
 
 SEXP sizeof_types(void) {
-  SEXP sizes = PROTECT(allocVector(INTSXP, 4));
-  SEXP nms = PROTECT(allocVector(STRSXP, 4)); // R style names
+  SEXP sizes = PROTECT(Rf_allocVector(INTSXP, 4));
+  SEXP nms = PROTECT(Rf_allocVector(STRSXP, 4)); // R style names
   int * s = INTEGER(sizes);
-  SET_STRING_ELT(nms, 0, mkChar("logical"));
+  SET_STRING_ELT(nms, 0, Rf_mkChar("logical"));
   s[0] = sizeof(int);
-  SET_STRING_ELT(nms, 1, mkChar("integer"));
+  SET_STRING_ELT(nms, 1, Rf_mkChar("integer"));
   s[1] = sizeof(int);
-  SET_STRING_ELT(nms, 2, mkChar("double"));
+  SET_STRING_ELT(nms, 2, Rf_mkChar("double"));
   s[2] = sizeof(double);
-  SET_STRING_ELT(nms, 3, mkChar("complex"));
+  SET_STRING_ELT(nms, 3, Rf_mkChar("complex"));
   s[3] = sizeof(Rcomplex);
-  setAttrib(sizes, R_NamesSymbol, nms);
+  Rf_setAttrib(sizes, R_NamesSymbol, nms);
   UNPROTECT(2);
   return sizes;
 }
